@@ -1,7 +1,7 @@
 /* Help strings.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna
-	Copyright (C) 1999-2021 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2022 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -574,21 +574,24 @@ const char * const FREEFORM_HELP[18] = {
   "opinion).  In this case, non-free-form.",
 };
 
-const char * const GOTOBOOKMARK_HELP[20] = {
-  "Syntax: GotoBookmark [N|+1|-1|-]",
+const char * const GOTOBOOKMARK_HELP[23] = {
+  "Syntax: GotoBookmark [N|+1|-1|<|>|-]|?]",
   "Abbreviation: GBM",
   "",
   "moves the cursor to the designated bookmark if that bookmark is set; see",
   "`SetBookmark'.  Each document has 10 available bookmarks",
-  "designated '0' to '9', plus the automatic bookmark designated by '-'.",
+  "designated '0' to '9', either end of the most recently pasted text block",
+  "designated '<' and '>', plus the automatic bookmark designated by '-'.",
   "If no option is given, '0' is assumed.  The options '+1' and '-1'",
   "indicate respectively the next and previous set bookmarks, so that",
   "repeated 'GotoBookmark +1' commands will cycle through all currently set",
-  "bookmarks.  When successful, the '-' automatic bookmark is set to the",
-  "position in the document from which the command was issued, so that",
-  "'GotoBookmark -' returns you to the location from which you last issued",
-  "a successful 'GotoBookmark' command.  Subsequent repeated 'GotoBookmark",
-  "-' commands will toggle you between the two locations.",
+  "numbered bookmarks.",
+  "",
+  "   When successful, the automatic bookmark '-' is set to the position in",
+  "the document from which the command was issued, so that 'GotoBookmark -'",
+  "returns you to the location from which you last issued a successful",
+  "'GotoBookmark' command.  Subsequent repeated 'GotoBookmark -' commands",
+  "will toggle you between the two locations.",
   "",
   "   The '?' option will cause 'GotoBookmark' to prompt you for a bookmark",
   "designation.  The promp will include an indication of which bookmarks",
@@ -722,7 +725,7 @@ const char * const INSERTTAB_HELP[7] = {
   "'Tabs' flag.  See `Tabs', `TabSize'.",
 };
 
-const char * const KEYCODE_HELP[12] = {
+const char * const KEYCODE_HELP[14] = {
   "Syntax: KeyCode [K]",
   "Abbreviation: KC",
   "",
@@ -733,7 +736,9 @@ const char * const KEYCODE_HELP[12] = {
   "can be useful while configuring your '~/.ne/.keys' file.",
   "",
   "   If the optional integer K (between 0 and 511) is given, 'KeyCode'",
-  "uses K as the key code and displays the information described above.",
+  "uses K as the key code and displays the information described above.  K",
+  "can be either decimal, hexadecimal if preceded by '0x', or octal if",
+  "preceded by '0'.",
 };
 
 const char * const LINEDOWN_HELP[6] = {
@@ -1154,22 +1159,32 @@ const char * const PARAGRAPH_HELP[24] = {
   "TeX for example is usually an excellent choice.",
 };
 
-const char * const PASTE_HELP[7] = {
+const char * const PASTE_HELP[12] = {
   "Syntax: Paste [N]",
   "Abbreviation: P",
   "",
   "pastes the contents of specified clip into the current document at the",
   "cursor position.  If you don't specify the clip number, the current clip",
   "is used; Specify which clip is current with `ClipNumber'.",
+  "",
+  "   Every time you paste into a document, a pair of bookmarks designated",
+  "by '<' and '>' mark the start and end points of the text you pasted.",
+  "Subsequently you can move to either end of a pasted block with the",
+  "'GotoBookmark <' or 'GotoBookmark >' commands.",
 };
 
-const char * const PASTEVERT_HELP[7] = {
+const char * const PASTEVERT_HELP[12] = {
   "Syntax: PasteVert [N]",
   "Abbreviation: PV",
   "",
   "vertically pastes the contents of the specified clip, the default being",
   "the current clip.  Each line of the clip is inserted on consecutive",
   "lines at the horizontal cursor position.",
+  "",
+  "   Every time you paste into a document, a pair of bookmarks designated",
+  "by '<' and '>' mark the start and end points of the text you pasted.",
+  "Subsequently you can move to either end of a pasted block with the",
+  "'GotoBookmark <' or 'GotoBookmark >' commands.",
 };
 
 const char * const PLAY_HELP[16] = {
@@ -1662,18 +1677,20 @@ const char * const SELECTDOC_HELP[25] = {
   "unsaved changes.  See `NextDoc', and `PrevDoc'.",
 };
 
-const char * const SETBOOKMARK_HELP[17] = {
-  "Syntax: SetBookmark [N|+1|-1|-|?]",
+const char * const SETBOOKMARK_HELP[19] = {
+  "Syntax: SetBookmark [N|+1|-1|<|>|-|?]",
   "Abbreviation: SBM",
   "",
   "sets a document bookmark to the current cursor position.  Each document",
-  "has 10 available bookmarks designated '0' to '9', plus the automatic",
+  "has 10 available bookmarks designated '0' to '9', the most recently",
+  "pasted block's start and end designated '<' and '>', plus the automatic",
   "bookmark designated by '-'.  If no option is given, '0' is assumed.",
   "Values of N from '0' to '9' set the Nth bookmark, while '+1' and '-1'",
   "indicate respectively the next and previous available unset bookmarks.",
-  "You can also set the '-' automatic bookmark, but it will be reset",
-  "automatically to the current position whenever a 'GotoBookmark' command",
-  "is issued.",
+  "You can also set the pasted block's start and end which will be reset on",
+  "the next 'Paste' or 'PasteVert' command, or the '-' automatic bookmark,",
+  "but it will be reset automatically to the current position whenever a",
+  "'GotoBookmark' command is issued.",
   "",
   "   The '?' option will cause 'SetBookmark' to prompt you for a bookmark",
   "designation.  The promp will include an indication of which bookmarks",
@@ -1975,17 +1992,19 @@ const char * const UNLOADMACROS_HELP[12] = {
   "version available.",
 };
 
-const char * const UNSETBOOKMARK_HELP[11] = {
-  "Syntax: UnsetBookmark [N|+1|-1|-|*]",
+const char * const UNSETBOOKMARK_HELP[13] = {
+  "Syntax: UnsetBookmark [N|+1|-1|<|>|-|*]",
   "Abbreviation: UBM",
   "",
-  "unsets either the Nth bookmark, the next (+1) or previous (-1) set",
-  "bookmarks, the automatic (-) bookmark, or all (*) bookmarks, making it",
-  "as if they had never been set; see `SetBookmark'.  If no option is",
-  "specified, N is assumed to be zero.  While you can unset the automatic",
-  "bookmark '-', it will be reset automatically to the current position",
-  "whenever a 'GotoBookmark' command is issued.  Each document's valid",
-  "bookmark designations are 0 to 9, and the '-' automatic bookmark.",
+  "unsets either the Nth bookmark (0 through 9), the next (+1) or previous",
+  "(-1) set bookmarks, the bookmarks designating the start (<) or end (>)",
+  "of the most recently pasted text block, the automatic (-) bookmark, or",
+  "all (*) bookmarks, making it as if they had never been set; see ",
+  "`SetBookmark'.  If no option is specified, N is assumed to be zero.",
+  "",
+  "   While you can unset the automatic bookmark '-', it will be reset",
+  "automatically to the current position whenever a 'GotoBookmark' command",
+  "is issued.",
 };
 
 const char * const UTF8_HELP[20] = {
