@@ -1,7 +1,7 @@
 /* Input class, key bindings and upper casing vector definitions.
 
    Copyright (C) 1993-1998 Sebastiano Vigna 
-   Copyright (C) 1999-2021 Todd M. Lewis and Sebastiano Vigna
+   Copyright (C) 1999-2022 Todd M. Lewis and Sebastiano Vigna
 
    This file is part of ne, the nice editor.
 
@@ -26,7 +26,10 @@ const char *input_class_names[INPUT_CLASS_COUNT] = {
 }; 
 
 const char *config_source_names[CONFIG_SOURCE_COUNT] = {
-	"Built In", "Global Prefs", "User Prefs", "Current Directory"
+	"Built In",
+	"Global Prefs",      "Global Prefs (terminal)",
+	"User Prefs",        "User Prefs (terminal)",
+	"Current Directory", "Current Directory (terminal)"
 }; 
 
 /* This vector contains all key bindings. Each entry points to a command line
