@@ -1,7 +1,7 @@
 /* Terminfo database scanning and keyboard escape sequence matching functions.
 
    Copyright (C) 1993-1998 Sebastiano Vigna 
-   Copyright (C) 1999-2021 Todd M. Lewis and Sebastiano Vigna
+   Copyright (C) 1999-2022 Todd M. Lewis and Sebastiano Vigna
 
    This file is part of ne, the nice editor.
 
@@ -347,21 +347,25 @@ void read_key_capabilities(void) {
 	key_may_set("\x1b?x",	NE_KEY_UP, BUILT_IN);
 	/*	key_may_set("\x1b" "A",	NE_KEY_UP, BUILT_IN);*/
 	key_may_set("\x1bOA",	NE_KEY_UP, BUILT_IN);
+	key_may_set("\x9b""A",	NE_KEY_UP, BUILT_IN);
 
 	key_may_set("\x1b[B",	NE_KEY_DOWN, BUILT_IN);
 	key_may_set("\x1b?r",	NE_KEY_DOWN, BUILT_IN);
 	/* key_may_set("\x1b" "B",	NE_KEY_DOWN, BUILT_IN);*/
 	key_may_set("\x1bOB",	NE_KEY_DOWN, BUILT_IN);
+	key_may_set("\x9b""B",	NE_KEY_DOWN, BUILT_IN);
 
 	key_may_set("\x1b[D",	NE_KEY_LEFT, BUILT_IN);
 	key_may_set("\x1b?t",	NE_KEY_LEFT, BUILT_IN);
 	/*key_may_set("\x1b" "D",	NE_KEY_LEFT, BUILT_IN);*/
 	key_may_set("\x1bOD",	NE_KEY_LEFT, BUILT_IN);
+	key_may_set("\x9b""D",	NE_KEY_LEFT, BUILT_IN);
 
 	key_may_set("\x1b[C",	NE_KEY_RIGHT, BUILT_IN);
 	key_may_set("\x1b?v",	NE_KEY_RIGHT, BUILT_IN);
 	/*key_may_set("\x1b" "C",	NE_KEY_RIGHT, BUILT_IN);*/
 	key_may_set("\x1bOC",	NE_KEY_RIGHT, BUILT_IN);
+	key_may_set("\x9b""C",	NE_KEY_RIGHT, BUILT_IN);
 
 	key_may_set("\x1b[1~",  NE_KEY_HOME, BUILT_IN);
 	key_may_set("\x1b[4~",  NE_KEY_END, BUILT_IN);
@@ -495,14 +499,14 @@ int get_key_code(void) {
 		if (cur_len) {
 
 			/* Something is already in the buffer. last_match is the position
-			we have to check. */
+			   we have to check. */
 
 			while(last_match < cur_len) {
 				if (last_match == 0 && io_utf8 && (unsigned char)kbd_buffer[0] >= 0x80) {
 					partial_is_utf8 = true;
 					last_match++;
 				}
-				else if (partial_is_utf8) { 	/* Our partial match is an UTF-8 sequence. */
+				else if (partial_is_utf8) {   /* Our partial match is an UTF-8 sequence. */
 					if ((kbd_buffer[last_match] & 0xC0) == 0x80) {
 						if (utf8len(kbd_buffer[0]) == ++last_match) {
 							c = utf8char(kbd_buffer);
@@ -519,7 +523,7 @@ int get_key_code(void) {
 				}
 				else {
 					/* First easy case. We felt off the array. We return the first character
-						in the buffer and restart the match. */
+					   in the buffer and restart the match. */
 
 					if (!key[cur_key].string) {
 						c = kbd_buffer[0];
@@ -528,8 +532,8 @@ int get_key_code(void) {
 					}
 
 					/* Second case. We have a partial match on the first last_match
-						characters. If another character matches, either the string is terminated,
-						and we return the key code, or we increment the match count. */
+					   characters. If another character matches, either the string is terminated,
+					   and we return the key code, or we increment the match count. */
 
 
 					else if (key[cur_key].string[last_match] == kbd_buffer[last_match]) {
@@ -544,12 +548,12 @@ int get_key_code(void) {
 					}
 
 					/* The tricky part. If there is a failed match, the order guarantees that
-						no match if possible if the code of the keyboard char is greater than the code of
-						the capability char. Otherwise, we check for the first capability starting
-						with the current keyboard characters. */
+					   no match is possible if the code of the keyboard char is greater than the code of
+					   the capability char. Otherwise, we check for the first capability starting
+					   with the current keyboard characters. */
 
 					else {
-						if (kbd_buffer[last_match] > key[cur_key].string[last_match]) {
+						if ((unsigned char)kbd_buffer[last_match] > (unsigned char)key[cur_key].string[last_match]) {
 							c = kbd_buffer[0];
 							if (--cur_len) memmove(kbd_buffer, kbd_buffer + 1, cur_len);
 							return (unsigned char)c;
@@ -689,10 +693,26 @@ char *cur_dir(void) {
 /* Key bindings override easily, so pull in any global bindings
    first, then override with the users bindings. */
 void get_key_bindings(const char * key_bindings_name) {
+   char * const term_name = getenv("TERM"), *key_bindings_term_name = NULL;
+
+	if (!key_bindings_name) key_bindings_name = KEY_BINDINGS_NAME;
+	key_bindings_term_name = malloc(strlen(key_bindings_name) + strlen(term_name) + 2);
+
+	if (key_bindings_term_name)
+		strcat(strcat(strcpy(key_bindings_term_name, key_bindings_name), "-"), term_name);
+
 	for (int i = 0; i < NUM_KEYS; i++) key_binding_source[i] = BUILT_IN;
-	get_key_bind(key_bindings_name, exists_gprefs_dir, GLOBAL_PREFS);
-	get_key_bind(key_bindings_name, exists_prefs_dir, USER_PREFS);
-	get_key_bind(key_bindings_name, cur_dir, CUR_DIR);
+
+	get_key_bind(key_bindings_name,      exists_gprefs_dir, GLOBAL_PREFS);
+	get_key_bind(key_bindings_term_name, exists_gprefs_dir, GLOBAL_PREFS_TERM);
+
+	get_key_bind(key_bindings_name,      exists_prefs_dir,  USER_PREFS);
+	get_key_bind(key_bindings_term_name, exists_prefs_dir,  USER_PREFS_TERM);
+
+	get_key_bind(key_bindings_name,      cur_dir,           CUR_DIR);
+	get_key_bind(key_bindings_term_name, cur_dir,           CUR_DIR_TERM);
+
+	free(key_bindings_term_name);
 }
 
 
