@@ -1,7 +1,7 @@
 /* Menu handling function. Includes also key and menu configuration parsing.
 
    Copyright (C) 1993-1998 Sebastiano Vigna
-   Copyright (C) 1999-2021 Todd M. Lewis and Sebastiano Vigna
+   Copyright (C) 1999-2022 Todd M. Lewis and Sebastiano Vigna
 
    This file is part of ne, the nice editor.
 
@@ -130,18 +130,20 @@ static const menu_item edit_item[] =
 
 static const menu_item search_item[] =
 	{
-		{ "Find...        ^F", FIND_ABBREV },
-		{ "Find RegExp... ^_", FINDREGEXP_ABBREV },
-		{ "Replace...     ^R", REPLACE_ABBREV },
-		{ "Replace Once...  ", REPLACEONCE_ABBREV },
-		{ "Replace All...   ", REPLACEALL_ABBREV },
-		{ "Repeat Last    ^G", REPEATLAST_ABBREV },
-		{ "Goto Line...   ^J", GOTOLINE_ABBREV },
-		{ "Goto Col...    [J", GOTOCOLUMN_ABBREV },
-		{ "Goto Mark        ", GOTOMARK_ABBREV },
-		{ "Match Bracket  ^]", MATCHBRACKET_ABBREV },
-		{ "Set Bookmark   [K", SETBOOKMARK_ABBREV },
-		{ "Goto Bookmark  [G", GOTOBOOKMARK_ABBREV }
+		{ "Find...          ^F", FIND_ABBREV },
+		{ "Find RegExp...   ^_", FINDREGEXP_ABBREV },
+		{ "Replace...       ^R", REPLACE_ABBREV },
+		{ "Replace Once...    ", REPLACEONCE_ABBREV },
+		{ "Replace All...     ", REPLACEALL_ABBREV },
+		{ "Repeat Last      ^G", REPEATLAST_ABBREV },
+		{ "Goto Line...     ^J", GOTOLINE_ABBREV },
+		{ "Goto Col...      [J", GOTOCOLUMN_ABBREV },
+		{ "Goto Mark          ", GOTOMARK_ABBREV },
+		{ "Goto Start Of Paste", "GBM <" },
+		{ "Goto End Of Paste  ", "GBM >" },
+		{ "Match Bracket    ^]", MATCHBRACKET_ABBREV },
+		{ "Set Bookmark     [K", SETBOOKMARK_ABBREV },
+		{ "Goto Bookmark    [G", GOTOBOOKMARK_ABBREV }
 	};
 
 
@@ -256,7 +258,7 @@ static menu def_menus[DEF_MENU_NUM] = {
 	{
 		sizeof(search_item) / sizeof(menu_item),
 		21,
-		17,
+		19,
 		0,
 		"Search",
 		search_item
@@ -697,7 +699,7 @@ void draw_status_bar(void) {
 		if (len < ne_columns - 1) {
 			if (cur_buffer->filename) {
 	 			/* This is a bit complicated because we have to compute the width of the filename first, and then
-				discard initial characters until the remaning part will fit. */
+				discard initial characters until the remaining part will fit. */
 
 				const int encoding = detect_encoding(cur_buffer->filename, strlen(cur_buffer->filename));
 				int pos = 0, width = get_string_width(cur_buffer->filename, strlen(cur_buffer->filename), encoding);
@@ -752,25 +754,27 @@ void print_message(const char * const message) {
 		msg_cache[MAX_MESSAGE_LENGTH - 1] = '\0';
 	}
 
-	if (message || showing_msg) {
-		move_cursor(ne_lines - 1, 0);
+	if (interactive_mode) {
+		if (message || showing_msg) {
+			move_cursor(ne_lines - 1, 0);
 
-		set_attr(0);
+			set_attr(0);
 
-		if (fast_gui || !standout_ok || !status_bar) {
-			clear_to_eol();
-			output_string(msg_cache, true);
+			if (fast_gui || !standout_ok || !status_bar) {
+				clear_to_eol();
+				output_string(msg_cache, true);
+			}
+			else {
+				standout_on();
+				output_string(msg_cache, true);
+				output_spaces(ne_columns - strlen(msg_cache), NULL);
+				standout_off();
+			}
+
+			fflush(stdout);
+
+			showing_msg = true;
 		}
-		else {
-			standout_on();
-			output_string(msg_cache, true);
-			output_spaces(ne_columns - strlen(msg_cache), NULL);
-			standout_off();
-		}
-
-		fflush(stdout);
-
-		showing_msg = true;
 	}
 }
 
