@@ -1,7 +1,7 @@
 /* main(), global initialization and global buffer functions.
 
    Copyright (C) 1993-1998 Sebastiano Vigna
-   Copyright (C) 1999-2021 Todd M. Lewis and Sebastiano Vigna
+   Copyright (C) 1999-2022 Todd M. Lewis and Sebastiano Vigna
 
    This file is part of ne, the nice editor.
 
@@ -36,7 +36,7 @@
 
 char *NO_WARRANTY_msg[] = {   PROGRAM_NAME " " VERSION ".",
 										"Copyright (C) 1993-1998 Sebastiano Vigna",
-										"Copyright (C) 1999-2021 Todd M. Lewis and Sebastiano Vigna",
+										"Copyright (C) 1999-2022 Todd M. Lewis and Sebastiano Vigna",
 										"",
 										"This program is free software; you can redistribute it and/or modify it under",
 										"the terms of the GNU General Public License as published by the Free Software",
@@ -102,6 +102,7 @@ bool req_order = true;
 #endif
 bool fast_gui;
 bool status_bar = true;
+bool interactive_mode;
 bool verbose_macros = true;
 /* end of global prefs */
 
@@ -330,7 +331,7 @@ int main(int argc, char **argv) {
 
 	add_head(&clips, &cd->cd_node);
 
-	/* General terminfo and cursor motion initalization. From here onwards,
+	/* General terminfo and cursor motion initialization. From here onwards,
 	   we cannot exit() lightly. */
 
 	term_init();
