@@ -1,7 +1,7 @@
 /* Main typedefs and defines.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna
-	Copyright (C) 1999-2021 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2022 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -79,7 +79,11 @@ typedef enum {
 extern const char *input_class_names[];
 
 typedef enum {
-	BUILT_IN, GLOBAL_PREFS, USER_PREFS, CUR_DIR, CONFIG_SOURCE_COUNT
+	BUILT_IN,
+	GLOBAL_PREFS, GLOBAL_PREFS_TERM,
+	USER_PREFS, USER_PREFS_TERM,
+	CUR_DIR, CUR_DIR_TERM,
+	CONFIG_SOURCE_COUNT
 } config_source;
 
 extern const char *config_source_names[];
@@ -150,6 +154,8 @@ typedef enum {
 enum {
 	MAX_USER_BOOKMARK = 9,
 	AUTO_BOOKMARK,
+	PASTE_START_BOOKMARK,
+	PASTE_END_BOOKMARK,
 	WORDWRAP_BOOKMARK,
 	NUM_BOOKMARKS
 };
@@ -606,6 +612,11 @@ extern bool req_order;
 extern bool status_bar;
 
 
+/* Track whether we are in interactive mode. */
+
+extern bool interactive_mode;
+
+
 /* If true, we want abbreviated screen updates. */
 
 extern bool fast_gui;
