@@ -1,7 +1,7 @@
 /* Requester handling.
 
    Copyright (C) 1993-1998 Sebastiano Vigna
-   Copyright (C) 1999-2021 Todd M. Lewis and Sebastiano Vigna
+   Copyright (C) 1999-2022 Todd M. Lewis and Sebastiano Vigna
 
    This file is part of ne, the nice editor.
 
@@ -126,7 +126,7 @@ typedef struct {
 	int entries;   /* how many entries on this page */
 	int cols;      /* columns fitting onto this page */
 	int rows;      /* rows fitting onto this page */
-	int col_width[MAX_REQ_COLS]; /* array of ints with width of each colummn */
+	int col_width[MAX_REQ_COLS]; /* array of ints with width of each column */
 } req_page_t;
 
 
@@ -544,8 +544,8 @@ static bool request_reorder(const int dir) {
 	if (! rl0->allow_reorder || rl.cur_entries < 2) return false;
 
 	/* p0 and p1 point to the strings we want to swap */
-	/* n0 and n1 are the indicies in   rl.entries[] for p0 and p1. (Also for rl.lengths[].) */
-	/* i0 and i1 are the indicies in rl0->entries[] for p0 and p1 */
+	/* n0 and n1 are the indices in   rl.entries[] for p0 and p1. (Also for rl.lengths[].) */
+	/* i0 and i1 are the indices in rl0->entries[] for p0 and p1 */
 	const int n0 = PCR2N(page, C, R);
 	const int n1 = (n0 + dir + rl.cur_entries ) % rl.cur_entries; /* Allows wrap around. */
 
@@ -593,8 +593,10 @@ static int rebuild_rl_entries() {
 	for (i = j = n = 0; i < rl0->cur_entries; i++) {
 		int orig = reverse_reorder(i);
 		char * const p1 = rl0->entries[orig];
-		D(fprintf(stderr, "rre: i:%d, j:%d, n:%d p0:%x p1:%x fuzz_len:%d rl.prune:%d\n",
-		       i, j, n, p0, p1, fuzz_len, rl.prune);)
+		D(fprintf(stderr, "rre: i:%d, j:%d, n:%d p0:%lx p1:%lx fuzz_len:%d rl.prune:%d\n",
+		                          i,    j,    n,
+		                            (unsigned long) p0,
+		                                   (unsigned long) p1,          fuzz_len,  rl.prune);)
 		if ( ! rl.prune || ! strncasecmp(p0, p1, fuzz_len) ) {
 			if (p1 == p0) {
 				n = j;
@@ -602,7 +604,7 @@ static int rebuild_rl_entries() {
 			}
 			rl.entries[j] = p1;
 			rl.lengths[j++] = rl0->lengths[orig];
-			D(fprintf(stderr, "rre: set rl.entries[%d] <- %x ('%s')\n", j-1, p1, p1);)
+			D(fprintf(stderr, "rre: set rl.entries[%d] <- %lx ('%s')\n", j-1, (unsigned long) p1, p1);)
 			D(fprintf(stderr, "rre: set rl.lengths[%d] <- rl0->lengths[%d] (%d)\n", j-1, orig, rl0->lengths[orig]);)
 		}
 	}
@@ -1487,7 +1489,7 @@ int req_list_init( req_list * const rli, int cmpfnc(const char *, const char *),
    suffix character, and an additional trailing '\0'. This allows comparing
    strings w/o having to consider the optional suffixes while adding entries to
    the req_list. Finalizing the req_list effectively shifts the suffixes left,
-   exchanging them for the preceeding '\0'. After this operation, all the
+   exchanging them for the preceding '\0'. After this operation, all the
    strings will be just normal C strings, some of which happen to end with the
    suffix character, and all of which are followed by two null bytes.
 
