@@ -1,7 +1,7 @@
 /* Search/replace functions (with and without regular expressions).
 
    Copyright (C) 1993-1998 Sebastiano Vigna
-   Copyright (C) 1999-2021 Todd M. Lewis and Sebastiano Vigna
+   Copyright (C) 1999-2022 Todd M. Lewis and Sebastiano Vigna
 
    This file is part of ne, the nice editor.
 
@@ -247,7 +247,7 @@ int replace(buffer * const b, const int n, const char * const string) {
 
 
 /* The following variables are used by regex. In particular, re_reg holds
-the stard/end of the extended replacement registers. */
+the start/end of the extended replacement registers. */
 
 static struct re_pattern_buffer re_pb;
 static struct re_registers re_reg;
