@@ -1,7 +1,7 @@
 /* Syntax highlighting from Joe's Own Editor: Syntax highlighting DFA interpreter.
 
    Copyright (C) 2004 Joseph H. Allen
-   Copyright (C) 2009-2021 Todd M. Lewis and Sebastiano Vigna
+   Copyright (C) 2009-2022 Todd M. Lewis and Sebastiano Vigna
 
    This file is part of ne, the nice editor.
 
@@ -217,7 +217,7 @@ HIGHLIGHT_STATE parse(struct high_syntax * const syntax, line_desc * const ld, H
 
 	/* Get next character */
 							/* Una iterazione in più: aggiungo '\n' come ultimo carattere. */
-	while( p <= q ) { /* On the last itteration, process the virtual '\n' character. */
+	while( p <= q ) { /* On the last iteration, process the virtual '\n' character. */
 		struct high_cmd *cmd, *kw_cmd;
 		int iters = -8; /* +8 extra iterations before cycle detect. */
 		int x;
